pub struct VersionData {
    pub version: u32,
    pub extension_data: Vec<u8>,
}

impl VersionData {
    pub fn deserialize(x: &[u8]) -> Result<VersionData, std::string::String> {
        if x.len() < 4 {
            return Err("Error parsing version from init packet header.".to_string());
        } else {
            let mut u32_byte_array: [u8; 4] = [0; 4];
            let mut extension_data = Vec::new();
            u32_byte_array.copy_from_slice(&x[0..4]);
            if x.len() > 4 {
                extension_data.extend(&x[4..]);
            }
            return Ok(VersionData {
                version: u32::from_be_bytes(u32_byte_array),
                extension_data: extension_data,
            });
        }
    }
    pub fn serialize(&self) -> Vec<u8> {
        let mut return_bytes = Vec::new();
        let u32_byte_array: [u8; 4] = self.version.to_be_bytes();
        return_bytes.extend(&u32_byte_array);
        if self.extension_data.len() > 0 {
            return_bytes.extend(&self.extension_data);
        }
        return_bytes
    }
}
